VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package clisymbols

Package {clisymbols}


Title: Unicode Symbols at the R Prompt
Version: 1.2.0
Description: A small subset of Unicode symbols, that are useful when building command line applications. They fall back to alternatives on terminals that do not support Unicode. Many symbols were taken from the 'figures' 'npm' package (see https://github.com/sindresorhus/figures).
License: MIT + file LICENSE
URL: https://github.com/gaborcsardi/clisymbols
BugReports: https://github.com/gaborcsardi/clisymbols/issues
Suggests: testthat
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2017-05-21 10:41:16 UTC; gaborcsardi
Author: Gábor Csárdi [aut, cre], Sindre Sorhus [aut]
Maintainer: Gábor Csárdi <csardi.gabor@gmail.com>
Repository: CRAN
Date/Publication: 2017-05-21 17:19:19 UTC

Various handy symbols to use in a command line UI

Description

Various handy symbols to use in a command line UI

Usage

symbol

Format

A named list, see names(symbol) for all sign names.

Details

On Windows they have a fallback to less fancy symbols.

Examples

cat(symbol$check, " SUCCESS\n", symbol$cross, " FAILURE\n", sep="")

## All symbols
cat(paste(format(names(symbol), width=20),
  unlist(symbol)), sep = "\n")

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.